Class: Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::GetConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb

Overview

Request message for GetConfig RPC.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. REQUIRED: The resource name of the config to be fetched. Format: organizations/{organization_id}/locations/global/config folders/{folder_id}/locations/global/config projects/{project_id}/locations/global/config projects/{project_number}/locations/global/config.

Returns:

  • (::String)

    Required. REQUIRED: The resource name of the config to be fetched. Format: organizations/{organization_id}/locations/global/config folders/{folder_id}/locations/global/config projects/{project_id}/locations/global/config projects/{project_number}/locations/global/config



35
36
37
38
# File 'proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb', line 35

class GetConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end