Class: Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb
Overview
Configuration for Data Lineage. Defines different configuration options for Lineage customers to control behaviour of lineage systems.
Defined Under Namespace
Classes: Ingestion
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#ingestion ⇒ ::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion
Optional.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. etag is used for optimistic concurrency control as a way
to help prevent simultaneous updates of a config from overwriting each
other. It is required that systems make use of the etag in the
read-modify-write cycle to perform config updates in order to avoid race
conditions: An etag is returned in the response to GetConfig, and
systems are expected to put that etag in the request to UpdateConfig to
ensure that their change will be applied to the same version of the config.
If an etag is not provided in the call to UpdateConfig, then the
existing config, if any, will be overwritten.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb', line 74 class Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines how Lineage should be ingested for a given resource. # @!attribute [rw] rules # @return [::Array<::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule>] # Optional. List of rules for Data Lineage ingestion. class Ingestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Ingestion rule for Data Lineage ingestion. # @!attribute [rw] integration_selector # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector] # Required. Integration selector of the rule. The rule is only applied to # the Integration selected by the selector. # @!attribute [rw] lineage_enablement # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::LineageEnablement] # Required. Lineage enablement configuration. Defines configurations for # the ingestion of lineage for the resource and its children. If # unspecified, the ingestion will be enabled only if it was configured in # the resource's parent. class IngestionRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration selector of the rule. The rule is only applied to the # Integration selected by the selector. # @!attribute [rw] integration # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector::Integration] # Required. Integration to which the rule applies. # This field can be used to specify the integration against which the # ingestion rule should be applied. class IntegrationSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration to which the rule applies. # This enum is expected to grow over time. module Integration # Integration is Unspecified INTEGRATION_UNSPECIFIED = 0 # Dataproc DATAPROC = 2 # Looker Core LOOKER_CORE = 3 end end # Lineage enablement configuration. Defines configurations for the # ingestion of lineage for the resource and its children. # @!attribute [rw] enabled # @return [::Boolean] # Optional. If true, ingestion of lineage should be enabled. If false, # it should be disabled. If unspecified, the system default value is # used. class LineageEnablement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#ingestion ⇒ ::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion
Returns Optional. Ingestion rule for Data Lineage ingestion.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb', line 74 class Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines how Lineage should be ingested for a given resource. # @!attribute [rw] rules # @return [::Array<::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule>] # Optional. List of rules for Data Lineage ingestion. class Ingestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Ingestion rule for Data Lineage ingestion. # @!attribute [rw] integration_selector # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector] # Required. Integration selector of the rule. The rule is only applied to # the Integration selected by the selector. # @!attribute [rw] lineage_enablement # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::LineageEnablement] # Required. Lineage enablement configuration. Defines configurations for # the ingestion of lineage for the resource and its children. If # unspecified, the ingestion will be enabled only if it was configured in # the resource's parent. class IngestionRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration selector of the rule. The rule is only applied to the # Integration selected by the selector. # @!attribute [rw] integration # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector::Integration] # Required. Integration to which the rule applies. # This field can be used to specify the integration against which the # ingestion rule should be applied. class IntegrationSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration to which the rule applies. # This enum is expected to grow over time. module Integration # Integration is Unspecified INTEGRATION_UNSPECIFIED = 0 # Dataproc DATAPROC = 2 # Looker Core LOOKER_CORE = 3 end end # Lineage enablement configuration. Defines configurations for the # ingestion of lineage for the resource and its children. # @!attribute [rw] enabled # @return [::Boolean] # Optional. If true, ingestion of lineage should be enabled. If false, # it should be disabled. If unspecified, the system default value is # used. class LineageEnablement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#name ⇒ ::String
Returns Identifier. The resource name of the config.
Format:
organizations/{organization_id}/locations/global/config
folders/{folder_id}/locations/global/config
projects/{project_id}/locations/global/config
projects/{project_number}/locations/global/config.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/datacatalog/lineage/configmanagement/v1/configmanagement.rb', line 74 class Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines how Lineage should be ingested for a given resource. # @!attribute [rw] rules # @return [::Array<::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule>] # Optional. List of rules for Data Lineage ingestion. class Ingestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Ingestion rule for Data Lineage ingestion. # @!attribute [rw] integration_selector # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector] # Required. Integration selector of the rule. The rule is only applied to # the Integration selected by the selector. # @!attribute [rw] lineage_enablement # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::LineageEnablement] # Required. Lineage enablement configuration. Defines configurations for # the ingestion of lineage for the resource and its children. If # unspecified, the ingestion will be enabled only if it was configured in # the resource's parent. class IngestionRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration selector of the rule. The rule is only applied to the # Integration selected by the selector. # @!attribute [rw] integration # @return [::Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::Config::Ingestion::IngestionRule::IntegrationSelector::Integration] # Required. Integration to which the rule applies. # This field can be used to specify the integration against which the # ingestion rule should be applied. class IntegrationSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Integration to which the rule applies. # This enum is expected to grow over time. module Integration # Integration is Unspecified INTEGRATION_UNSPECIFIED = 0 # Dataproc DATAPROC = 2 # Looker Core LOOKER_CORE = 3 end end # Lineage enablement configuration. Defines configurations for the # ingestion of lineage for the resource and its children. # @!attribute [rw] enabled # @return [::Boolean] # Optional. If true, ingestion of lineage should be enabled. If false, # it should be disabled. If unspecified, the system default value is # used. class LineageEnablement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |